# Develop in a notebook

One of the main design goals for Panel was to make it seamless to work across development environments. This section will provide simple how-to guides on how to develop with Panel in an notebook environment.

::::{grid} 1 2 2 3
:gutter: 1 1 1 2

:::{grid-item-card} {octicon}`note;2.5em;sd-mr-1 sd-animate-grow50` Display output in notebooks
:link: notebook
:link-type: doc

How to display output in Jupyter and non-Jupyter based notebook environments.
:::

:::{grid-item-card} {octicon}`moon;2.5em;sd-mr-1 sd-animate-grow50` Preview apps in JupyterLab
:link: jupyterlabpreview
:link-type: doc

How to use the Preview functionality in JupyterLab to rapidly develop applications.
:::

:::{grid-item-card} {octicon}`rows;2.5em;sd-mr-1 sd-animate-grow50` Develop in other notebook environments
:link: other_nb
:link-type: doc

How to develop apps in Google Colab, VSCode notebook, nteract, and other notebook environments.
:::

::::

```{toctree}
:titlesonly:
:hidden:
:maxdepth: 2

notebook
jupyterlab
other_nb
```
